echo off;
% NUMERICAL METHODS: MATLAB Programs, (c) John H. Mathews 1994
% To accompany the text:
% NUMERICAL METHODS for Mathematics, Science and Engineering, 2nd Ed, 1992
% Prentice Hall, Englewood Cliffs, New Jersey, 07632, U.S.A.
% This free software is complements of the author.

% Algorithm 7.5 (Adaptive Quadrature Using Simpson's Rule).
% Section	7.4,	Adaptive Quadrature, Page 389
% This program is to be used for pedagogical purposes.
echo on; clc; format long; hold off; clear

% This program implements adaptive quadrature.

%	Define and store the function f(x)	in the M-file  f.m 
% function y = f(x)
% y = 13.*(x - x.^2).*exp(-3.*x./2);

delete f.m
diary f.m; disp('function y = f(x)');...
           disp('y = 13.*(x - x.^2).*exp(-3.*x./2);');...
diary off;

f(0); % Remark. f.m adapt.m srule.m are used for Algorithm 7.5

pause	% Press any key to see the graph y = f(x).

clc; clg;
a = 0;
b = 4;
h = (b-a)/200;
X = a:h:b;
Y = f(X);
c = -1.5;
d = 2;
axis([a b c d]);...
plot(X,Y,'g');...
hold on;...
plot([a b],[0 0],'b',[0 0],[c d],'b');...
xlabel('x');...
ylabel('y');...
title('The curve y = f(x) over [a,b].');...
grid;...
axis;...
hold off;...
shg; pause	% Press any key to continue.

clc;

% Adaptive quadrature is applied over the interval [a,b].

%	Place the endpoints of [a,b] in  a  and  b.

% Place the tolerance in  toler.

a  = 0;
b  = 4;
toler = 0.00001;

[SRmat,quad,err] = adapt('f',a,b,toler);

pause	% Press any key to continue.

clc;
Mx1 = 'The adaptive quadrature approximation is: ';
Mx2 = '   quadrature value   +- error bound';
clc,echo off,diary output,...
disp(''),disp(Mx1),disp(''),...
disp(Mx2),disp([quad err]),diary off,echo on

pause % Press any key to continue.

clg; 
X0 = [SRmat(:,1)',b];
Y0 = f(X0);
Z0 = zeros(1,length(X0));
axis([a b c d]);...
plot(X,Y,'g',X0,Y0,'or',X0,Z0,'+r');...
hold on;...
plot([a b],[0 0],'b',[0 0],[c d],'b');...
xlabel('x');...
ylabel('y');...
title('Adaptive quadrature.');...
grid;...
axis;...
hold off;...
shg; pause	% Press any key to continue.

Mx3 = 'Quadrature over each subinterval:';
Mx4 = '   a(k)               b(k)               S(a(k),b(k))';
clc,echo off,diary output,disp(''),disp(Mx3),disp(''),...
disp(Mx4),disp(SRmat(:,[1 2 4])),...
disp(['    S(a(k),b(k))      error(k)']),...
disp(Mx2),disp([quad err]),diary off,echo on

